OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Tiến trình của người dùng đã hết hạn một cách không được mong đợi trước",
    "Provided email-address is not valid" : "Thư điện tử được cung cấp không khả dụng",
    "%s has published the calendar »%s«" : "%s vừa đăng tải thông tin vào lịch »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Một lỗi không mong đợi khi đang gửi thư điện tử. Vui lòng liên hệ quản trị viên của bạn",
    "Successfully sent email to " : "Đã hoàn thành việc gửi thư điện tử đến",
    "Hello," : "Xin chào,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Chúng tôi muốn thông báo với bạn rằng %s vừa đăng tải thông tin vào lịch calendar »%s«.",
    "Open »%s«" : "Mở »%s«",
    "Cheers!" : "Xin chúc mừng!",
    "Upcoming events" : "Các sự kiện sắp diễn ra",
    "Calendar" : "Lịch",
    "A Calendar app for Nextcloud" : "Một ứng dụng Lịch nhắc nhở cho Hệ thống",
    "Previous day" : "Ngày trước",
    "Previous week" : "Tuần trước",
    "Previous month" : "Tháng trước",
    "Next day" : "Ngày hôm sau",
    "Next week" : "Tuần sau",
    "Next month" : "Tháng sau",
    "+ New event" : "+ Sự kiện mới",
    "Today" : "Hôm nay",
    "Day" : "Ngày",
    "Week" : "Tuần",
    "Month" : "Tháng",
    "List" : "Danh sách",
    "Untitled calendar" : "Lịch không tiêu đề",
    "Edit name" : "Sửa đổi tên",
    "Saving name …" : "Đang lưu tên  …",
    "Edit color" : "Sửa đổi màu",
    "Saving color …" : "Đang sửa đổi màu  …",
    "Copy private link" : "Sao chép liên kết riêng tư",
    "Download" : "Tải về",
    "Unshare from me" : "Gỡ chia sẻ khỏi tôi",
    "Delete" : "Xóa",
    "An error occurred, unable to change visibility of the calendar." : "Một lỗi đã xảy ra, không thể thay đổi tính hiển thị của lịch.",
    "An error occurred, unable to delete the calendar." : "Một lỗi đã xảy ra, không thể xóa lịch.",
    "Calendar link copied to clipboard." : "Liên kết của lịch đã được sao chép vào bảng tạm.",
    "Calendar link could not be copied to clipboard." : "Liên kết của lịch không thể sao chép vào bảng tạm.",
    "An error occurred, unable to rename the calendar." : "Một lỗi đã xảy ra, không thể đổi tên của lịch.",
    "An error occurred, unable to change the calendar's color." : "Một lỗi đã xảy ra, không thể thay đổi màu sắc của lịch.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Đang gỡ chia sẻ của lịch trong {countdown} giây"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Đang xóa lịch trong {countdown} giây"],
    "Share link" : "Liên kết chia sẽ",
    "Publish calendar" : "Công khai lịch",
    "Publishing calendar" : "Đang công khai lịch",
    "Copy public link" : "Sao chép liên kết công khai",
    "Send link to calendar via email" : "Gửi liên kết đến lịch thông qua thư điện tử",
    "Enter one address" : "Điền vào môt địa chỉ",
    "Sending email …" : "Đang gửi email ...",
    "Copy subscription link" : "Sao chép liên kết theo dõi ",
    "Copying link …" : "Sao chép liên kết  ...",
    "Copied link" : "Liên kết đã được sao chép",
    "Could not copy link" : "Không thể sao chép liên kết",
    "Copy embedding code" : "Đang sao chép mã nhúng",
    "Copying code …" : "Đang sao chép mã  ...",
    "Copied code" : "Đã sao chép dòng lệnh",
    "Could not copy code" : "Không thể sao chép dòng lệnh",
    "Delete share link" : "Xóa liên kết chia sẻ",
    "Deleting share link …" : "Đang xóa liên kết chia sẻ  ...",
    "An error occurred, unable to publish calendar." : "Có lỗi đã xảy ra, không thể công khai lịch.",
    "An error occurred, unable to send email." : "Một lỗi đã xảy ra, không thể gửi email.",
    "Embed code copied to clipboard." : "Mã nhúng đã được sao chép vào bảng tạm.",
    "Embed code could not be copied to clipboard." : "Mã nhúng không thể được sao chép vào bảng tạm.",
    "Unpublishing calendar failed" : "Gỡ công khai cho lịch thất bại",
    "Share with users or groups" : "Chia sẽ với người dùng hoặc nhóm",
    "No users or groups" : "Không có người dùng hay nhóm",
    "can edit" : "có thể chỉnh sửa",
    "Unshare with {displayName}" : "Gỡ chia sẻ với {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Một lỗi đã xảy ra, không thể thay đổi thuộc tính chia sẻ của lịch ",
    "An error occurred, unable to change the permission of the share." : "Một lỗi đã diễn ra, không thể thay đổi quyền hạn chia sẻ",
    "+ New calendar" : "+ Lịch mới",
    "New calendar" : "Lịch mới",
    "Creating calendar …" : "Đang tạo lịch  …",
    "New calendar with task list" : "Lịch mới với danh sách nhiệm vụ",
    "New subscription from link (read-only)" : "Đăng kí theo dõi mới từ liên kết (Chỉ-đọc)",
    "Creating subscription …" : "Đang tạo đăng kí theo dõi mới  …",
    "An error occurred, unable to create the calendar." : "Một lỗi đã xảy ra, không thẻ tạo lịch.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vui lòng nhập vào một liên kết khả dụng ( bắt đầu với http://, https://, webcal://, hoặc webcals://)",
    "Could not update calendar order." : "Không thể cập nhật thứ tự của lịch",
    "Import calendars" : "Nhập lịch",
    "Please select a calendar to import into …" : "Vui lòng chọn một lịch để nhập vào  …",
    "Filename" : "Tên tập tin",
    "Calendar to import into" : "Lịch để nhập vào",
    "Cancel" : "Hủy",
    "_Import calendar_::_Import calendars_" : ["Nhập lịch"],
    "{filename} is an unsupported file-type" : "{filename}  là một kiểu loại tệp không được hỗ trợ",
    "{filename} could not be parsed" : "{filename} không thể được phân tách",
    "No valid files found, aborting import" : "Không có tệp khả dụng được tìm thấy, đang hủy quá trình nhập",
    "Import partially failed. Imported {accepted} out of {total}." : "Quá trình nhập thất bại 1 phần. Đã nhập {accepted} trong tổng {total}.",
    "_Successfully imported %n event_::_Successfully imported %n events._" : [" %n sự kiện đã được nhập thành công"],
    "Automatic" : "Tự động",
    "Automatic ({detected})" : " ({detected}) tự động",
    "New setting was not saved successfully." : "Thiết lập mới không được lưu thành công",
    "Shortcut overview" : "Bản xem trước của lối tắt",
    "or" : "hoặc",
    "Previous period" : "Kỳ trước",
    "Next period" : "Kỳ tiếp theo",
    "Day view" : "Xem theo ngày",
    "Week view" : "Xem theo tuần",
    "Month view" : "Xem theo tháng",
    "Actions" : "Hành động",
    "Create event" : "Tạo sự kiện mới",
    "Show shortcuts" : "Hiển thị các lối tắt",
    "Enable birthday calendar" : "Bật lịch sinh nhật",
    "Show tasks in calendar" : "Cho thấy nhiệm vụ trong lịch",
    "Enable simplified editor" : "Bật chỉnh sửa đơn giản",
    "Limit visible events per view" : "Hạn chế các sự kiện có thể thấy trên mỗi lượt xem",
    "Show weekends" : "Cho thấy ngày cuối tuần",
    "Show week numbers" : "Hiển thị số tuần",
    "Copy primary CalDAV address" : "Sao chép địa chỉ CalDAV chính",
    "Copy iOS/macOS CalDAV address" : "Sao chép địa chỉ CalDAV cho iOS/macOC",
    "Show keyboard shortcuts" : "Hiển thị các phím tắt",
    "Settings & import" : "Thiết lập & Nhập vào",
    "CalDAV link copied to clipboard." : "Liên kết CalDAV đã được sao chép vào bảng tạm",
    "CalDAV link could not be copied to clipboard." : "Liên kết CalDAV không thể được sao chép vào bảng tạm.",
    "before at" : "trước lúc",
    "Notification" : "Thông báo",
    "Email" : "Thư điện tử",
    "Audio notification" : "Thông báo âm thanh",
    "Other notification" : "Các thông báo khác",
    "Relative to event" : "Liên quan tới sự kiện",
    "On date" : "Vào ngày",
    "Edit time" : "Chỉnh sửa thời gian",
    "Save time" : "Lưu thời gian",
    "Remove reminder" : "Gỡ bỏ lịch nhắc hẹn",
    "on" : "trên",
    "at" : "vào lúc",
    "+ Add reminder" : "+ Thêm lịch nhắc hẹn",
    "_second_::_seconds_" : ["giây"],
    "_minute_::_minutes_" : ["phút"],
    "_hour_::_hours_" : ["giờ"],
    "_day_::_days_" : ["ngày"],
    "_week_::_weeks_" : ["tuần"],
    "No reminders yet" : "Chưa có lịch nhắc hẹn nào ",
    "Availability of attendees, resources and rooms" : "Tình trạng tham gia của người dự, nguồn lực và phòng ",
    "Busy (tentative)" : "Bận (có khả năng thay đổi)",
    "Busy" : "Bận",
    "Out of office" : "Không ở văn phòng",
    "Unknown" : "Không xác định",
    "{name} accepted your invitation." : "{name}  đã chấp nhận lời mởi của bạn.",
    "{name} accepted {organizerName}'s invitation." : "{name} đã chấp nhận lời mời của {organizerName}",
    "{name} declined your invitation." : "{name} đã từ chối lời mơi của bạn",
    "{name} declined {organizerName}'s invitation." : "{name} đã từ chối lời mời của {organizerName}",
    "{name} has delegated their invitation." : "{name} đã ủy thác lời mời của họ",
    "{name} marked their participation as tentative." : "{name} đã đánh dấu sự tham dự của họ với trạng thái không chắc chắn",
    "{name} did not respond to your invitation yet." : "{name} chưa trả lời lời mời của bạn",
    "{name} did not respond to {organizerName}'s invitation yet." : "{name} chưa trả lời cho lời mời của {organizerName}",
    "Create Talk room for this event" : "Tạo một phòng trò chuyện cho sự kiện này",
    "Show busy times" : "Cho thấy các thời gian bận",
    "Successfully appended link to talk room to description." : "Liên kết đã được thêm thành công vào mô tả trong phòng trò chuyện ",
    "Error creating Talk room" : "Có lõi xảy ra khi tạo phòng Trò chuyện",
    "Send e-mail" : "Gửi email",
    "Chairperson" : "Chủ tịch",
    "Required participant" : "Người tham gia được yêu cầu",
    "Optional participant" : "Người tham gia không bắt buộc",
    "Non-participant" : "Người không tham gia",
    "Remove attendee" : "Gỡ bỏ người tham gia",
    "Search for e-mails, users, contacts, resources or rooms" : "Tìm kiếm cho email, người dùng, liên hệ, nguồn lực hoặc phòng ốc",
    "No match found" : "Không có khớp lệnh nào được tìm thấy",
    "No attendees yet" : "Chưa có giờ tham gia",
    "(organizer)" : "(organizer)",
    "Remove color" : "Gỡ màu",
    "Event title" : "Tiêu đề sự kiện",
    "All day" : "Cả ngày",
    "Can not modify all-day setting for events that are part of a recurrence-set." : "Không thể chỉnh sửa thiết lập cho cả-ngày dành cho các sự kiện có một phần là của sự kiện lặp lại",
    "from {startDate}" : "từ {startDate}",
    "from {startDate} at {startTime}" : "từ {startDate} vào lúc {startTime}",
    "to {endDate}" : "đến  {endDate}",
    "to {endDate} at {endTime}" : "đến {endDate} vào lúc {endTime}",
    "End repeat" : "Kết thúc lập lại",
    "Select to end repeat" : "Chọn thời gian kết thúc lặp lại",
    "never" : "không thay đổi",
    "on date" : "vào ngày",
    "after" : "sau khi",
    "_time_::_times_" : ["lần"],
    "This event is the recurrence-exception of a recurrence-set. You can not add a recurrence-rule to it." : "Sự kiện này là một sự kiện không có trong chũi sự kiện lặp lại. bạn không thể thêm vào một luật lệ lặp lại cho nó. ",
    "first" : "đầu tiên",
    "third" : "vị trí thứ ba",
    "fourth" : "vị trí thứ tư",
    "fifth" : "vị trí thứ năm",
    "second to last" : "kế cuối",
    "last" : "cuối cùng",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "các thay đổi đến luật lệ định kỳ này sẽ chỉ áp dụng cho định kỳ này và các định kỳ tương lai của nó ",
    "Repeat" : "Lặp lại",
    "Repeat every" : "Lặp lại mỗi",
    "By day of the month" : "Vào ngày của tháng",
    "On the" : "trên",
    "_month_::_months_" : ["tháng"],
    "_year_::_years_" : ["năm"],
    "Monday" : "Thứ 2",
    "weekday" : "ngày làm việc",
    "weekend day" : "ngày cuối tuần",
    "Summary" : "tóm tắt",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Định nghĩa về định kỳ của sự kiện này không hoàn toàn được hỗ trợ bởi Nextcloud. Nếu bạn sửa các lựa chọn định kỳ này, một vài định kỳ có thể sẽ bị mất ",
    "More" : "hơn",
    "Save" : "Lưu",
    "Update" : "Cập nhật",
    "Update this occurrence" : "Cập nhập định kỳ này",
    "Update this and all future" : "Cập nhập định kỳ này và cho toàn bộ tương lai",
    "Public calendar does not exist" : "Lịch công khai không tồn tại",
    "Maybe the share was deleted or has expired?" : "Có lẽ chia sẽ đã bị xóa hoặc hết hạn ? ",
    "Please select a timezone:" : "Vui lòng chọn múi giờ:",
    "Pick a time" : "chọn thời gian",
    "Pick a date" : "Chọn ngày",
    "from {formattedDate}" : "từ {formattedDate}",
    "to {formattedDate}" : "đến {formattedDate}",
    "on {formattedDate}" : "vào {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "từ  {formattedDate} vào lúc {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "đến {formattedDate} vào lúc {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "vào {formattedDate} vào lúc {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} vào lúc {formattedTime}",
    "Please enter a valid date" : "Vui lòng điền vào 1 ngày khả dụng",
    "Please enter a valid date and time" : "Vui lòng điền vào 1 ngày và thời gian khả dụng",
    "Type to search timezone" : "Nhập để tìm kiếm múi giờ",
    "Personal" : "Cá nhân",
    "The automatic timezone detection determined your timezone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your timezone manually in the calendar settings." : "Tự động phát hiện múi giờ xác định múi giờ của bạn trên hệ thống UTC. \nĐây gần như là một trong những kết quả của các phương thức bảo mật của trình duyệt của bạn.\nVui lòng đặt múi giờ của bạn một cách thủ công trong các thiết lập của Lịch. ",
    "Your configured timezone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your timezone in the settings and report this issue." : "Múi giờ được cấu hình của bạn ({timezoneId}) không được tìm thấy. Đang trở về lại hệ thống UTC.\nVui lòng thay đổi múi giờ của bạn trong Thiết lập và báo cáo vấn đề này. ",
    "No more events today" : "Không có thêm sự kiện nào hôm nay",
    "Event does not exist" : "Sự kiện không tồn tại",
    "Delete this occurrence" : "Xóa định kỳ này",
    "Delete this and all future" : "Xóa địnhy kỳ này và tất cả tương lai của nó",
    "Details" : "Chi tiết",
    "Attendees" : "Người tham gia",
    "Reminders" : "Nhắc nhở",
    "Close" : "Đóng",
    "Show more details" : "Cho thấy thêm chi tiết",
    "Subscribe to {name}" : "Dõi theo {name}",
    "Download {name}" : "Tải xuống {name}",
    "Anniversary" : "Ngày kỷ niệm",
    "Appointment" : "Cuộc hẹn",
    "Business" : "Doanh nghiệp",
    "Education" : "Giáo dục",
    "Holiday" : "Ngày lễ",
    "Meeting" : "Cuộc họp",
    "Miscellaneous" : "Hỗn hợp",
    "Non-working hours" : "Ngoài giờ làm việc",
    "Not in office" : "Ngoài văn phòng",
    "Phone call" : "Cuộc gọi",
    "Sick day" : "Ngày nghỉ ốm",
    "Special occasion" : "Dịp đặc biệt",
    "Travel" : "Du lịch",
    "Vacation" : "Kì nghỉ",
    "Midnight on the day the event starts" : "Giữa đêm vào ngày mà sự kiện bắt đầu",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n ngày trước khi sự kiện bắt đầu vào lúc {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n tuần trước khi sự kiện bắt đầu vào lúc {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "vào ngày sự kiện bắt đầu vào lúc {formattedHourMinute}",
    "at the event's start" : "Vào lúc sự kiện bắt đầu",
    "at the event's end" : "vào lúc sự kiện kết thúc",
    "{time} before the event starts" : "{time} trước khi sự kiện bắt đầu",
    "{time} before the event ends" : "{time} trước khi sự kiện kết thúc",
    "{time} after the event starts" : "{time} sau khi sự kiện bắt đầu",
    "{time} after the event ends" : "{time} sau khi sự kiện kết thúc",
    "on {time}" : "vào  {time}",
    "on {time} ({timezoneId})" : "vào {time} ({timezoneId})",
    "Week {number} of {year}" : "Tuần thứ {number} của năm {year}",
    "Does not repeat" : "Không lặp lại",
    "Daily" : "Hằng ngày",
    "Weekly" : "Hằng tuần",
    "Monthly" : "Hằng tháng",
    "Yearly" : "Hằng năm",
    "_Every %n day_::_Every %n days_" : ["Mỗi %n ngày"],
    "_Every %n week_::_Every %n weeks_" : ["Mỗi %n tuần"],
    "_Every %n month_::_Every %n months_" : ["Mỗi %n tháng"],
    "_Every %n year_::_Every %n years_" : ["Mỗi %n năm"],
    "_on {weekday}_::_on {weekdays}_" : ["vào  {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["vào các ngày {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "vào  {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "trong {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "trong {monthNames} trên {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "cho đến {untilDate}",
    "_%n time_::_%n times_" : ["%n lần"],
    "Untitled event" : "Sự kiện không tiêu đề",
    "Untitled task" : "Nhiệm vụ không tiêu đề",
    "Please ask your administrator to enable the Tasks App." : "Vui lòng hỏi quản trị viên của bạn để bật ứng dụng Nhiệm Vụ",
    "prev" : "trước",
    "next" : "tiếp theo",
    "prev year" : "năm trước",
    "next year" : "năm tới",
    "today" : "hôm nay",
    "list" : "danh sách",
    "W" : "w",
    "all-day" : "nguyên-ngày",
    "%n more" : "thêm %n",
    "No events to display" : "không có sự kiện để hiển thị",
    "_+%n more_::_+%n more_" : ["+ thêm %n "],
    "No events" : "không có sự kiện",
    "Create a new event or change the visible time-range" : "Tạo sự kiện mới hoặc thay đổi khung thời gian hiển thị",
    "It might have been deleted, or there was a typo in a link" : "Đường dẫn có thể đã bị xóa, hoặc đã có lỗi đánh máy trong liên kết",
    "It might have been deleted, or there was a typo in the link" : "Đường dẫn có thể đã bị xóa, hoặc đã có lỗi đánh máy trong liên kết",
    "When shared show" : "Khi được chia sẻ thì cho thấy",
    "When shared show full event" : "Khi được chia sẻ thì cho thấy đầy đủ sự kiện",
    "When shared show only busy" : "Khi được chia sẻ thì chỉ cho thấy đang bận",
    "When shared hide this event" : "Khi được chia sẻ thì ẩn sự kiện này đi",
    "The visibility of this event in shared calendars." : "Khả năng nhìn thấy của sự kiện này trong các lịch được chia sẻ",
    "Location" : "Vị trí",
    "Add a location" : "Thêm vào một địa điểm",
    "Description" : "Mô tả",
    "Add a description" : "Thêm vào một mô tả",
    "Status" : "Trạng thái",
    "Confirmed" : "Đã xác nhận",
    "Tentative" : "Chưa chắc chắn",
    "Canceled" : "Đã bị hủy",
    "Confirmation about the overall status of the event." : "Sự xác nhận về tình trạng tổng thể của sự kiện.",
    "Show as" : "Cho thấy với",
    "Take this event into account when calculating free-busy information." : "Lưu ý sự kiện này vào tài khoản khi tính toán về thông tin bận-rãnh",
    "Free" : "Rãnh",
    "Categories" : "Các hạng mục",
    "Categories help you to structure and organize your events." : "Các hạng mục này giúp bạn lên sườn và sắp xếp các sự kiện của bạn",
    "Search or add categories" : "Tìm kiếm và thêm vào các hạng mục",
    "Add this as a new category" : "Thêm mục này như là hạng mục mới",
    "Custom color" : "Tùy chỉnh màu",
    "Special color of this event. Overrides the calendar-color." : "Dùng màu đặc biệt cho sự kiện này. Ghi đè lên màu hiện hành",
    "Chat room for event" : "Phòng trò chuyện cho sự kiện",
    "Imported {filename}" : " {filename} đã được nhập",
    "Meditation" : "Thiền",
    "Relaxing" : "Thư giãn",
    "Relax" : "Thư giãn",
    "Presentation" : "Buổi thuyết trình",
    "Present" : "Trình bày",
    "Camping" : "Cắm trại",
    "Camp" : "Cắm trại",
    "Movie" : "Phim ảnh",
    "Cinema" : "Rạp chiếu phim",
    "Graduation" : "Lễ tốt nghiệp",
    "Brainstorm" : "Động não",
    "Baseball" : "Bóng chày",
    "Meet" : "Gặp gỡ",
    "Planning" : "Lên kế hoạch",
    "Pointing" : "Đánh dấu",
    "Retrospective" : "Nhìn nhận lại",
    "Review" : "Đánh giá",
    "Office" : "Văn phòng",
    "Contributor week" : "Tuần lễ đóng góp",
    "Party" : "Tiệc tùng",
    "Celebration" : "Lễ kỉ niệm",
    "Mail" : "Thư điện tử",
    "Soccer" : "Đá banh",
    "Football" : "Bóng bầu dục",
    "Gaming" : "Chơi game",
    "Play" : "Play",
    "Game" : "Trò chơi",
    "Drive" : "Lái xe",
    "Bicycle" : "Xep đạp",
    "Cycle" : "Đi xe đạp",
    "Biking" : "Đạp xe",
    "Podcast" : "Podcast",
    "Basketball" : "Bóng rổ",
    "Fishing" : "Câu cá",
    "Hiking" : "Leo núi",
    "Hike" : "Leo",
    "Art" : "Nghệ thuật",
    "Exhibition" : "Triễn lãm",
    "Museum" : "Nhà bảo tàng",
    "Pilates" : "Thể dục kết hợp cường độ thấp",
    "Park" : "Công viên",
    "Studying" : "Học bài",
    "Doctor" : "Bác sĩ",
    "Health" : "Sức khỏe",
    "Dentist" : "Nha sĩ",
    "Interview" : "Phỏng vấn",
    "Training" : "Luyện tập",
    "Practice" : "Tập luyện",
    "Sports" : "Các môn thể thao",
    "Exercise" : "Tập thể dục",
    "Work out" : "Tập thể dục",
    "Working out" : "Tập thể dục",
    "Gym" : "Gym",
    "Barber" : "Thợ cắt tóc",
    "Haircut" : "Cắt tóc",
    "Exam" : "Thi",
    "Working" : "Làm việc",
    "New Years Eve" : "Đêm giao thừa",
    "NYE" : "NYE",
    "Fireworks" : "Pháo hoa",
    "Running" : "Chạy bộ",
    "Go for a run" : "Đi chạy bộ",
    "Marathon" : "Chạy marathon",
    "Video-conference" : "Hội nghị video",
    "Conference-call" : "Hội nghị qua điện thoại",
    "Video-call" : "Cuộc gọi video",
    "Video-chat" : "Trò chuyện video",
    "Video-meeting" : "Họp qua video",
    "Call" : "Cuộc gọi",
    "Calling" : "Đang gọi",
    "Christmas" : "Giáng sinh",
    "Conference" : "Họp",
    "Pizza" : "Pizza",
    "Travelling" : "Đi du lịch",
    "Journey" : "Cuộc phiêu lưu",
    "Collaborate" : "Hợp tác",
    "Pair" : "Kết đôi ",
    "Lecture" : "Bài giảng",
    "Seminar" : "Hội thảo",
    "Photograph" : "Bức ảnh",
    "Celebrate" : "Ăn mừng",
    "Shopping" : "Đi mua sắm",
    "Skate" : "Đi trượt ván",
    "Skateboard" : "Ván trượt",
    "Wine tasting" : "Thử rựu",
    "Golf" : "Đánh gôn",
    "Dinner" : "Dùng bữa tối",
    "Lunch" : "Ăn trưa",
    "Global" : "Chung"
},
"nplurals=1; plural=0;");
